{% extends "djpress/base.html" %}
{% load djpress_tags %}

{% block main %}

  <article>
    <header>
      <h1>{% post_title_link %}</h1>
      <p>By {% post_author_link %}. {% post_date_link %}</p>
    </header>
    <section>
      {% post_content %}
    </section>
    <footer>
      <p>Categories: {% post_categories_link "span" "badge" %}</p>
    </footer>
  </article>

  {% posts_nav_links %}

{% endblock main %}
